==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-clock/clock_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation>&lt;базується на локалі&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">Налаштування годинника LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>Налаштування годинника</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Час</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>Показувати &amp;секунди</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>12-&amp;годинний стиль</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>&amp;Використати UTC</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>Формат д&amp;ати</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>&amp;Не показувати дату</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>Показувати дату &amp;перед часом</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>Показувати дату пі&amp;сля часу</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>Показати дату під часом в новій &amp;лінійці </translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation>Перший день тижна в календарі</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>Орієнтація</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>Автоповертання коли панель є вертикальна</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="vanished">&amp;Шрифт</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">Шрифт</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">Показувати &amp;дату</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">Формат д&amp;ати</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation type="vanished">Шриф&amp;т</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">Показувати дату в &amp;новому рядку</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation type="vanished">&amp;Використовувати шрифти з теми</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation type="vanished">Шрифт часу</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation type="vanished">Шрифт дати</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation type="vanished">Надтонкий</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="vanished">Тонкий</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation type="vanished">Дуже темний</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="vanished">Темний</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">Жирний</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation type="vanished">Напівжирний</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Нахилений</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>Введіть власний формат дати</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation>Розпізнавальні комбінації формату дати є наступні:

d	день числом без нуля (1 to 31)
dd	день числом з нулем (01 to 31)
ddd	абревіатура локалізованої назви дня (наприклад &apos;Пон&apos; до &apos;Нед&apos;).
dddd	довга локалізована назва дня (наприклад &apos;Понеділок&apos; до &apos;Неділя&apos;).
M	місяць числом без нуля (1-12)
MM	місяць числом з нулем (01-12)
MMM	абревіатура локалізованої назви місяця (наприклад &apos;Січ&apos; до &apos;Груд&apos;).
MMMM	довга локалізована назва місяця (наприклад &apos;Січень&apos; до &apos;Грудень&apos;).
yy	рік двома цифрами (00-99)
yyyy	рік чотирма цифрами

Всі інші вхідні символи трактуються як текст.
Всі комбінації символів, що поміщені в одинарні лапки (&apos;)
будуть теж трактуватися як текст і не будуть використовуватися у виразі.


Власний формат дати:</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-clock/clock_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation>&lt;базується на локалі&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClock</name>
    <message>
        <location filename="../../../lxqtclock.cpp" line="57"/>
        <source>Date&amp;Time (clock) plugin is deprecated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="58"/>
        <source>The &lt;strong&gt;clock&lt;/strong&gt; plugin is deprecated and will be removed in future version of LXQt. Consider replacing it with &lt;strong&gt;worldclock&lt;/strong&gt;.&lt;br/&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="60"/>
        <source>don&apos;t show this again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">Налаштування годинника LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>Налаштування годинника</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Час</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>Показувати &amp;секунди</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>12-&amp;годинний стиль</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>&amp;Використати UTC</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>Формат д&amp;ати</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>&amp;Не показувати дату</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>Показувати дату &amp;перед часом</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>Показувати дату пі&amp;сля часу</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>Показати дату під часом в новій &amp;лінійці </translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation>Перший день тижна в календарі</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>Орієнтація</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>Автоповертання коли панель є вертикальна</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="vanished">&amp;Шрифт</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">Шрифт</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">Показувати &amp;дату</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">Формат д&amp;ати</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation type="vanished">Шриф&amp;т</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">Показувати дату в &amp;новому рядку</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation type="vanished">&amp;Використовувати шрифти з теми</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation type="vanished">Шрифт часу</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation type="vanished">Шрифт дати</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation type="vanished">Надтонкий</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="vanished">Тонкий</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation type="vanished">Дуже темний</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="vanished">Темний</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">Жирний</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation type="vanished">Напівжирний</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Нахилений</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>Введіть власний формат дати</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation>Розпізнавальні комбінації формату дати є наступні:

d	день числом без нуля (1 to 31)
dd	день числом з нулем (01 to 31)
ddd	абревіатура локалізованої назви дня (наприклад &apos;Пон&apos; до &apos;Нед&apos;).
dddd	довга локалізована назва дня (наприклад &apos;Понеділок&apos; до &apos;Неділя&apos;).
M	місяць числом без нуля (1-12)
MM	місяць числом з нулем (01-12)
MMM	абревіатура локалізованої назви місяця (наприклад &apos;Січ&apos; до &apos;Груд&apos;).
MMMM	довга локалізована назва місяця (наприклад &apos;Січень&apos; до &apos;Грудень&apos;).
yy	рік двома цифрами (00-99)
yyyy	рік чотирма цифрами

Всі інші вхідні символи трактуються як текст.
Всі комбінації символів, що поміщені в одинарні лапки (&apos;)
будуть теж трактуватися як текст і не будуть використовуватися у виразі.


Власний формат дати:</translation>
    </message>
</context>
</TS>
